@@ -21,7 +21,7 @@ use English                qw(-no_match_vars);
 use Carp                   qw(carp croak confess);
 use Cwd                    qw();
 
-our $VERSION     = '1.01';
+our $VERSION     = '1.02';
 our @EXPORT      = qw();
 our @EXPORT_OK   = qw(dist_pkgname dist_pkgver);
 our %EXPORT_TAGS = ( 'all' => [ @EXPORT_OK ] );
@@ -83,9 +83,16 @@ END_OVERRIDES
 my $TT_MOD_NAME;
 my @TT_MOD_SEARCH = qw/ Template Template::Alloy Template::Tiny /;
 
-my $TT_IF_MATCH  = qr/ \[% -? \s* IF \s* (\w*) \s* -? %\] \n? /xms;
-my $TT_END_MATCH = qr/ \[% -? \s* END          \s* -? %\] \n? /xms;
-my $TT_VAR_MATCH = qr/ \[% -? \s* (\w+)        \s* -? %\] \n? /xms;
+sub _tt_block
+{
+    my $inside = shift;
+    return qr{ \[% -?
+               \s* $inside \s*
+               (?: (?: -%\] \n* ) | %\] ) }xms;
+}
+my $TT_IF_MATCH  = _tt_block 'IF \s* (\w*)';
+my $TT_END_MATCH = _tt_block 'END';
+my $TT_VAR_MATCH = _tt_block '(\w+)';
 
 # Crude template for our PKGBUILD script
 my $PKGBUILD_TEMPL = <<'END_TEMPL';
@@ -627,6 +634,14 @@ sub set_tt_init_args
     return $self->status->tt_init_args( { @_ } );
 }
 
+sub set_tt_module
+{
+    my ($self, $modname) = @_;
+
+    $TT_MOD_NAME = $modname || 0;
+    return $TT_MOD_NAME;
+}
+
 sub get_tt_module
 {
     _load_tt_module() unless defined $TT_MOD_NAME;
